@@ -903,6 +903,9 @@ class Thalassa:
 					height INTEGER NOT NULL,
 					duration INTEGER NOT NULL,
 					owner TEXT NOT NULL,
+					thumbnail TEXT NOT NULL,
+					summary TEXT NOT NULL,
+					clip TEXT NOT NULL,
 					UNIQUE(file_id) ON CONFLICT IGNORE
 				);'''
 				cursor.execute(sql)
